pub struct SelectPrompt { /* private fields */ }Expand description
Selection prompt for choosing from a list of options Selection prompt for choosing from a list of options
Implementations
Sourceimpl SelectPrompt
impl SelectPrompt
Sourcepub fn new(title: &str, options: Vec<String>) -> Self
pub fn new(title: &str, options: Vec<String>) -> Self
Create a new select prompt with title and options
Sourcepub fn handle_key(&mut self, key: KeyEvent) -> SelectResult
pub fn handle_key(&mut self, key: KeyEvent) -> SelectResult
Handle keyboard input Handle keyboard input
Sourcepub fn selected_text(&self) -> Option<&str>
pub fn selected_text(&self) -> Option<&str>
Get selected option text